@@ -29,6 +29,8 @@ Commands = GlobalCommands()
 os.environ['HOST_HOME'] = os.getenv("HOME", "")
 os.environ['ODOO_HOME'] = str(SCRIPT_DIRECTORY)
 
+class NoProjectNameException(Exception): pass
+
 def _get_default_project_name(restrict):
     def _get_project_name_from_file(path):
         if not path.exists():
@@ -46,40 +48,15 @@ def _get_default_project_name(restrict):
         if pj:
             return pj
 
-    root = Path(_get_customs_root(Path(os.getcwd())))
-    if (root / "MANIFEST").exists():
-        return root.name
-    raise Exception("No default project name could be determined.")
+    customs_root = _get_customs_root(Path(os.getcwd()))
+    if customs_root:
+        root = Path(customs_root)
+        if (root / "MANIFEST").exists():
+            return root.name
+    raise NoProjectNameException("No default project name could be determined.")
 
 pass_config = click.make_pass_decorator(Config, ensure=True)
 
-def install_completion_callback(ctx, attr, value):
-    def setup_for_shell_generic(shell, shell_call):
-        path = Path(f"/etc/{shell}_completion.d")
-        NAME = shell_call.upper().replace("-", "_")
-        if '_source' in (os.getenv(f"_{NAME}_COMPLETE") or ''):
-            sys.exit(0)
-        completion = subprocess.check_output([sys.argv[0]], env={f"_{NAME}_COMPLETE": f"{shell}_source"}, shell=True)
-        if path.exists():
-            if os.access(path, os.W_OK):
-                (path / shell_call).write_bytes(completion)
-                return
-
-        if not (path / shell_call).exists():
-            rc = Path(os.path.expanduser("~")) / f'.{shell}rc'
-            if not rc.exists():
-                return
-            complete_file = rc.parent / f'.{shell_call}-completion.sh'
-            complete_file.write_bytes(completion)
-            if complete_file.name not in rc.read_text():
-                content = rc.read_text()
-                content += '\nsource ~/' + complete_file.name
-                rc.write_text(content)
-
-    name = Path(sys.argv[0]).name
-    setup_for_shell_generic(shellingham.detect_shell()[0], name)
-    sys.exit(0)
-
 
 @click.group(cls=AliasedGroup)
 @click.option("-f", "--force", is_flag=True)
@@ -88,12 +65,8 @@ def install_completion_callback(ctx, attr, value):
 @click.option("-xd", '--restrict-docker-compose', multiple=True, help="Several parameters; limit to special configuration files settings and docker-compose files. All other configuration files will be ignored.")
 @click.option("-p", '--project-name', help="Set Project-Name")
 @click.option("--chdir", help="Set Working Directory")
-@click.option("--install-completion", is_flag=True)
 @pass_config
-def cli(config, force, verbose, project_name, restrict_setting, restrict_docker_compose, chdir, install_completion):
-    if install_completion:
-        install_completion_callback()
-        return
+def cli(config, force, verbose, project_name, restrict_setting, restrict_docker_compose, chdir):
     config.force = force
     config.verbose = verbose
     config.restrict = {}
@@ -102,7 +75,7 @@ def cli(config, force, verbose, project_name, restrict_setting, restrict_docker_
         config.WORKING_DIR = chdir
     if not config.WORKING_DIR:
         # usually all need a working except cicd
-        if 'init' not in sys.argv:
+        if not any(x in sys.argv for x in ['init', 'install-completion']):
             click.secho("Please enter into an odoo directory, which contains a MANIFEST file.", fg='red')
             sys.exit(1)
 
@@ -120,9 +93,12 @@ def cli(config, force, verbose, project_name, restrict_setting, restrict_docker_
     if project_name:
         config.project_name = project_name
     else:
-        config.project_name = _get_default_project_name(config.restrict['settings'])
+        try:
+            config.project_name = _get_default_project_name(config.restrict['settings'])
+        except NoProjectNameException:
+            config.project_name = ""
     os.environ['project_name'] = config.project_name
-    os.environ['docker_compose'] = str(config.files['docker_compose'])
+    os.environ['docker_compose'] = str(config.files.get('docker_compose')) or ''
 
     load_dynamic_modules(config.dirs['images'])
 
@@ -143,4 +119,30 @@ from . import lib_turnintodev # NOQA
 # import container specific commands
 from .tools import abort # NOQA
 from .tools import __dcrun # NOQA
-from .tools import __dc # NOQA
\ No newline at end of file
+from .tools import __dc # NOQA
+
+@cli.command()
+def install_completion():
+    def setup_for_shell_generic(shell, shell_call):
+        path = Path(f"/etc/{shell}_completion.d")
+        NAME = shell_call.upper().replace("-", "_")
+        completion = subprocess.check_output([sys.argv[0]], env={f"_{NAME}_COMPLETE": f"{shell}_source"}, shell=True)
+        if path.exists():
+            if os.access(path, os.W_OK):
+                (path / shell_call).write_bytes(completion)
+                return
+
+        if not (path / shell_call).exists():
+            rc = Path(os.path.expanduser("~")) / f'.{shell}rc'
+            if not rc.exists():
+                return
+            complete_file = rc.parent / f'.{shell_call}-completion.sh'
+            complete_file.write_bytes(completion)
+            if complete_file.name not in rc.read_text():
+                content = rc.read_text()
+                content += '\nsource ~/' + complete_file.name
+                rc.write_text(content)
+
+    name = Path(sys.argv[0]).name
+    setup_for_shell_generic(shellingham.detect_shell()[0], name)
+    sys.exit(0)
